Push

Trait Push 

pub trait Push<B> {
    // Required methods
    fn push_all(
        &self,
        url: &Url,
        body: B,
        content_type: &str,
    ) -> impl Future<Output = Result<()>> + Send;
    fn push_add(
        &self,
        url: &Url,
        body: B,
        content_type: &str,
    ) -> impl Future<Output = Result<()>>;
}
Push is a trait that defines the interface for the implementation of your own http client of choice.

Required Methods

fn push_all( &self, url: &Url, body: B, content_type: &str, ) -> impl Future<Output = Result<()>> + Send

fn push_add( &self, url: &Url, body: B, content_type: &str, ) -> impl Future<Output = Result<()>>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors